@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Dump;
 
-our $DATE = '2017-07-07'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2018-11-22'; # DATE
+our $VERSION = '0.120'; # VERSION
 
 use 5.010001;
 use strict;
@@ -209,7 +209,7 @@ Perinci::CmdLine::Dump - Run a Perinci::CmdLine-based script but only to dump th
 
 =head1 VERSION
 
-This document describes version 0.11 of Perinci::CmdLine::Dump (from Perl distribution Perinci-CmdLine-Dump), released on 2017-07-07.
+This document describes version 0.120 of Perinci::CmdLine::Dump (from Perl distribution Perinci-CmdLine-Dump), released on 2018-11-22.
 
 =for Pod::Coverage ^(dump_perinci_cmdline_script)$
 
@@ -220,7 +220,7 @@ This document describes version 0.11 of Perinci::CmdLine::Dump (from Perl distri
 
 Usage:
 
- dump_pericmd_script(%args) -> [status, msg, result, meta]
+ dump_pericmd_script(%args) -> [status, msg, payload, meta]
 
 Run a Perinci::CmdLine-based script but only to dump the object.
 
@@ -278,7 +278,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -306,7 +306,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
